pub fn send(method: &str, params: Value) -> Result<Value, ClientError>Expand description
Send a single request to the default socket path. On success returns the
reply’s result value; an in-band application error is
ClientError::Remote.
pub fn send(method: &str, params: Value) -> Result<Value, ClientError>Send a single request to the default socket path. On success returns the
reply’s result value; an in-band application error is
ClientError::Remote.