pub fn try_connect() -> Result<UnixStream, ClientError>Expand description
Connect to the Scrybe socket at the default location. “Not running” is the
typed ClientError::SocketUnavailable — check ClientError::is_not_running.
pub fn try_connect() -> Result<UnixStream, ClientError>Connect to the Scrybe socket at the default location. “Not running” is the
typed ClientError::SocketUnavailable — check ClientError::is_not_running.